==> wagtail-seo-0.0.3.tar.gz: wagtail-seo-0.0.3/README.md <==
Wagtail SEO
===========

Search engine and social media optimization for Wagtail.

(Work in progress - currently in ALPHA status)

[Source code on GitHub](https://github.com/coderedcorp/wagtail-seo) |
[Documentation](https://docs.coderedcorp.com/wagtail-seo/) |
[PyPI](https://pypi.org/project/wagtail-seo/)


Status
------

|                        |                      |
|------------------------|----------------------|
| Python Package         | [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/wagtail-seo)](https://pypi.org/project/wagtail-seo/) [![PyPI - Django Version](https://img.shields.io/pypi/djversions/wagtail-seo)](https://pypi.org/project/wagtail-seo/) [![PyPI - Wheel](https://img.shields.io/pypi/wheel/wagtail-seo)](https://pypi.org/project/wagtail-seo/) [![PyPI - Downloads](https://img.shields.io/pypi/dm/wagtail-seo)](https://pypi.org/project/wagtail-seo/) [![PyPI](https://img.shields.io/pypi/v/wagtail-seo)](https://pypi.org/project/wagtail-seo/) |
| Build                  | [![Build Status](https://dev.azure.com/coderedcorp/cr-github/_apis/build/status/wagtail-seo?branchName=main)](https://dev.azure.com/coderedcorp/wagtail-seo/_build/latest?definitionId=13&branchName=main) [![Azure DevOps tests (branch)](https://img.shields.io/azure-devops/tests/coderedcorp/cr-github/13/main)](https://dev.azure.com/coderedcorp/cr-github/_build/latest?definitionId=13&branchName=main) [![Azure DevOps coverage (branch)](https://img.shields.io/azure-devops/coverage/coderedcorp/cr-github/13/main)](https://dev.azure.com/coderedcorp/cr-github/_build/latest?definitionId=13&branchName=main) |


Getting Started
---------------

Follow the [getting started guide](https://docs.coderedcorp.com/wagtail-seo/getting-started/).


Contributing
------------

The goal of Wagtail SEO is to become the most complete, go-to package for doing
SEO on Wagtail. This means it will not only provide the features, but will
continually stay up to date with evolving SEO practices and data standards (and
Google's whims). That being said we heartily welcome contributions!

Follow the [contributing guide](https://docs.coderedcorp.com/wagtail-seo/contributing.html)
to get your development environment setup.

==> wagtail-seo-1.0.1.tar.gz: wagtail-seo-1.0.1/README.md <==
Wagtail SEO
===========

Search engine and social media optimization for Wagtail.

[Source code on GitHub](https://github.com/coderedcorp/wagtail-seo) |
[Documentation](https://docs.coderedcorp.com/wagtail-seo/) |
[PyPI](https://pypi.org/project/wagtail-seo/)


Status
------

|                        |                      |
|------------------------|----------------------|
| Python Package         | [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/wagtail-seo)](https://pypi.org/project/wagtail-seo/) [![PyPI - Django Version](https://img.shields.io/pypi/djversions/wagtail-seo)](https://pypi.org/project/wagtail-seo/) [![PyPI - Wheel](https://img.shields.io/pypi/wheel/wagtail-seo)](https://pypi.org/project/wagtail-seo/) [![PyPI - Downloads](https://img.shields.io/pypi/dm/wagtail-seo)](https://pypi.org/project/wagtail-seo/) [![PyPI](https://img.shields.io/pypi/v/wagtail-seo)](https://pypi.org/project/wagtail-seo/) |
| Build                  | [![Build Status](https://dev.azure.com/coderedcorp/cr-github/_apis/build/status/wagtail-seo?branchName=main)](https://dev.azure.com/coderedcorp/cr-github/_build/latest?definitionId=13&branchName=main) [![Azure DevOps tests (branch)](https://img.shields.io/azure-devops/tests/coderedcorp/cr-github/13/main)](https://dev.azure.com/coderedcorp/cr-github/_build/latest?definitionId=13&branchName=main) [![Azure DevOps coverage (branch)](https://img.shields.io/azure-devops/coverage/coderedcorp/cr-github/13/main)](https://dev.azure.com/coderedcorp/cr-github/_build/latest?definitionId=13&branchName=main) |


Getting Started
---------------

Follow the [getting started guide](https://docs.coderedcorp.com/wagtail-seo/getting-started/).


Contributing
------------

The goal of Wagtail SEO is to become the most complete, go-to package for doing
SEO on Wagtail. This means it will not only provide the features, but will
continually stay up to date with evolving SEO practices and data standards (and
Google's whims). That being said we heartily welcome contributions!

Follow the [contributing guide](https://docs.coderedcorp.com/wagtail-seo/contributing.html)
to get your development environment setup.
